#[non_exhaustive]pub struct CreateDaemonOutputBuilder { /* private fields */ }Expand description
A builder for CreateDaemonOutput.
Implementations
Sourceimpl CreateDaemonOutputBuilder
impl CreateDaemonOutputBuilder
Sourcepub fn daemon_arn(self, input: impl Into<String>) -> Self
pub fn daemon_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the daemon.
Sourcepub fn set_daemon_arn(self, input: Option<String>) -> Self
pub fn set_daemon_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the daemon.
Sourcepub fn get_daemon_arn(&self) -> &Option<String>
pub fn get_daemon_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the daemon.
Sourcepub fn status(self, input: DaemonStatus) -> Self
pub fn status(self, input: DaemonStatus) -> Self
The status of the daemon.
Sourcepub fn set_status(self, input: Option<DaemonStatus>) -> Self
pub fn set_status(self, input: Option<DaemonStatus>) -> Self
The status of the daemon.
Sourcepub fn get_status(&self) -> &Option<DaemonStatus>
pub fn get_status(&self) -> &Option<DaemonStatus>
The status of the daemon.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The Unix timestamp for the time when the daemon was created.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The Unix timestamp for the time when the daemon was created.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The Unix timestamp for the time when the daemon was created.
Sourcepub fn deployment_arn(self, input: impl Into<String>) -> Self
pub fn deployment_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the initial daemon deployment. This deployment places daemon tasks on each container instance of the specified capacity providers.
Sourcepub fn set_deployment_arn(self, input: Option<String>) -> Self
pub fn set_deployment_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the initial daemon deployment. This deployment places daemon tasks on each container instance of the specified capacity providers.
Sourcepub fn get_deployment_arn(&self) -> &Option<String>
pub fn get_deployment_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the initial daemon deployment. This deployment places daemon tasks on each container instance of the specified capacity providers.
Sourcepub fn build(self) -> CreateDaemonOutput
pub fn build(self) -> CreateDaemonOutput
Consumes the builder and constructs a CreateDaemonOutput.