#[non_exhaustive]pub struct CreateDaemonOutput {
pub daemon_arn: Option<String>,
pub status: Option<DaemonStatus>,
pub created_at: Option<DateTime>,
pub deployment_arn: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.daemon_arn: Option<String>The Amazon Resource Name (ARN) of the daemon.
status: Option<DaemonStatus>The status of the daemon.
created_at: Option<DateTime>The Unix timestamp for the time when the daemon was created.
deployment_arn: Option<String>The Amazon Resource Name (ARN) of the initial daemon deployment. This deployment places daemon tasks on each container instance of the specified capacity providers.
Implementations
Sourceimpl CreateDaemonOutput
impl CreateDaemonOutput
Sourcepub fn daemon_arn(&self) -> Option<&str>
pub fn daemon_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the daemon.
Sourcepub fn status(&self) -> Option<&DaemonStatus>
pub fn status(&self) -> Option<&DaemonStatus>
The status of the daemon.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The Unix timestamp for the time when the daemon was created.
Sourcepub fn deployment_arn(&self) -> Option<&str>
pub fn deployment_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the initial daemon deployment. This deployment places daemon tasks on each container instance of the specified capacity providers.
Sourceimpl CreateDaemonOutput
impl CreateDaemonOutput
Sourcepub fn builder() -> CreateDaemonOutputBuilder
pub fn builder() -> CreateDaemonOutputBuilder
Creates a new builder-style object to manufacture CreateDaemonOutput.