#[non_exhaustive]pub struct ListDaemonTaskDefinitionsOutputBuilder { /* private fields */ }Expand description
A builder for ListDaemonTaskDefinitionsOutput.
Implementations
Sourceimpl ListDaemonTaskDefinitionsOutputBuilder
impl ListDaemonTaskDefinitionsOutputBuilder
Sourcepub fn daemon_task_definitions(self, input: DaemonTaskDefinitionSummary) -> Self
pub fn daemon_task_definitions(self, input: DaemonTaskDefinitionSummary) -> Self
Appends an item to daemon_task_definitions.
To override the contents of this collection use set_daemon_task_definitions.
The list of daemon task definition summaries.
Sourcepub fn set_daemon_task_definitions(
self,
input: Option<Vec<DaemonTaskDefinitionSummary>>,
) -> Self
pub fn set_daemon_task_definitions( self, input: Option<Vec<DaemonTaskDefinitionSummary>>, ) -> Self
The list of daemon task definition summaries.
Sourcepub fn get_daemon_task_definitions(
&self,
) -> &Option<Vec<DaemonTaskDefinitionSummary>>
pub fn get_daemon_task_definitions( &self, ) -> &Option<Vec<DaemonTaskDefinitionSummary>>
The list of daemon task definition summaries.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
The nextToken value to include in a future ListDaemonTaskDefinitions request. When the results of a ListDaemonTaskDefinitions request exceed maxResults, this value can be used to retrieve the next page of results.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
The nextToken value to include in a future ListDaemonTaskDefinitions request. When the results of a ListDaemonTaskDefinitions request exceed maxResults, this value can be used to retrieve the next page of results.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
The nextToken value to include in a future ListDaemonTaskDefinitions request. When the results of a ListDaemonTaskDefinitions request exceed maxResults, this value can be used to retrieve the next page of results.
Sourcepub fn build(self) -> ListDaemonTaskDefinitionsOutput
pub fn build(self) -> ListDaemonTaskDefinitionsOutput
Consumes the builder and constructs a ListDaemonTaskDefinitionsOutput.