#[non_exhaustive]pub struct DaemonTaskDefinitionSummary {
pub arn: Option<String>,
pub registered_at: Option<DateTime>,
pub registered_by: Option<String>,
pub delete_requested_at: Option<DateTime>,
pub status: Option<DaemonTaskDefinitionStatus>,
}Expand description
A summary of a daemon task definition.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.arn: Option<String>The Amazon Resource Name (ARN) of the daemon task definition.
registered_at: Option<DateTime>The Unix timestamp for the time when the daemon task definition was registered.
registered_by: Option<String>The principal that registered the daemon task definition.
delete_requested_at: Option<DateTime>The Unix timestamp for the time when the daemon task definition delete was requested.
status: Option<DaemonTaskDefinitionStatus>The status of the daemon task definition.
Implementations
Sourceimpl DaemonTaskDefinitionSummary
impl DaemonTaskDefinitionSummary
Sourcepub fn arn(&self) -> Option<&str>
pub fn arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the daemon task definition.
Sourcepub fn registered_at(&self) -> Option<&DateTime>
pub fn registered_at(&self) -> Option<&DateTime>
The Unix timestamp for the time when the daemon task definition was registered.
Sourcepub fn registered_by(&self) -> Option<&str>
pub fn registered_by(&self) -> Option<&str>
The principal that registered the daemon task definition.
Sourcepub fn delete_requested_at(&self) -> Option<&DateTime>
pub fn delete_requested_at(&self) -> Option<&DateTime>
The Unix timestamp for the time when the daemon task definition delete was requested.
Sourcepub fn status(&self) -> Option<&DaemonTaskDefinitionStatus>
pub fn status(&self) -> Option<&DaemonTaskDefinitionStatus>
The status of the daemon task definition.
Sourceimpl DaemonTaskDefinitionSummary
impl DaemonTaskDefinitionSummary
Sourcepub fn builder() -> DaemonTaskDefinitionSummaryBuilder
pub fn builder() -> DaemonTaskDefinitionSummaryBuilder
Creates a new builder-style object to manufacture DaemonTaskDefinitionSummary.