#[non_exhaustive]pub struct InferenceAccelerator {
pub device_name: String,
pub device_type: String,
}This feature is no longer available.
Details on an Elastic Inference accelerator. For more information, see Working with Amazon Elastic Inference on Amazon ECS in the Amazon Elastic Container Service Developer Guide.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.device_name: StringThis feature is no longer available.
The Elastic Inference accelerator device name. The deviceName must also be referenced in a container definition as a ResourceRequirement.
device_type: StringThis feature is no longer available.
The Elastic Inference accelerator type to use.
Implementations
Sourceimpl InferenceAccelerator
impl InferenceAccelerator
Sourcepub fn device_name(&self) -> &str
pub fn device_name(&self) -> &str
The Elastic Inference accelerator device name. The deviceName must also be referenced in a container definition as a ResourceRequirement.
Sourcepub fn device_type(&self) -> &str
pub fn device_type(&self) -> &str
The Elastic Inference accelerator type to use.
Sourceimpl InferenceAccelerator
impl InferenceAccelerator
Sourcepub fn builder() -> InferenceAcceleratorBuilder
pub fn builder() -> InferenceAcceleratorBuilder
Creates a new builder-style object to manufacture InferenceAccelerator.