#[non_exhaustive]pub struct InferenceAcceleratorOverride {
pub device_name: Option<String>,
pub device_type: Option<String>,
}This feature is no longer available.
Details on an Elastic Inference accelerator task override. This parameter is used to override the Elastic Inference accelerator specified in the task definition. For more information, see Working with Amazon Elastic Inference on Amazon ECS in the Amazon Elastic Container Service Developer Guide.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.device_name: Option<String>This feature is no longer available.
The Elastic Inference accelerator device name to override for the task. This parameter must match a deviceName specified in the task definition.
device_type: Option<String>This feature is no longer available.
The Elastic Inference accelerator type to use.
Implementations
Sourceimpl InferenceAcceleratorOverride
impl InferenceAcceleratorOverride
Sourcepub fn device_name(&self) -> Option<&str>
pub fn device_name(&self) -> Option<&str>
The Elastic Inference accelerator device name to override for the task. This parameter must match a deviceName specified in the task definition.
Sourcepub fn device_type(&self) -> Option<&str>
pub fn device_type(&self) -> Option<&str>
The Elastic Inference accelerator type to use.
Sourceimpl InferenceAcceleratorOverride
impl InferenceAcceleratorOverride
Sourcepub fn builder() -> InferenceAcceleratorOverrideBuilder
pub fn builder() -> InferenceAcceleratorOverrideBuilder
Creates a new builder-style object to manufacture InferenceAcceleratorOverride.